BaseDropdown<T> class abstract

Inheritance
Implementers

Constructors

BaseDropdown({Key? key, List<DropDownModel<T>> initData = const [], DropDownModel<T>? selectedValue, String? labelText, String? hintText, dynamic onOptionSelected(DropDownModel<T>?)?, String? validator(DropDownModel<T>?)?, DropdownDecoration? decoration, Widget? arrowWidget, DropdownType dropdownType = DropdownType.expandable, bool disabled = false, Future<List<DropDownModel<T>>>? asyncInitData, bool closeOnTapOutside = true, List<DropDownNestedModel<T>>? nestedInitData, Future<List<DropDownNestedModel<T>>>? asyncNestedInitData, double expandableSelectorBottomMargin = 4})
const

Properties

arrowWidget → Widget?
Widget displayed for the dropdown arrow icon.
final
asyncInitData → Future<List<DropDownModel<T>>>?
Future that provides the initial list of dropdown options.
final
asyncNestedInitData → Future<List<DropDownNestedModel<T>>>?
Future that provides the initial list of dropdown options.
final
closeOnTapOutside → bool
Base class for dropdown widgets.
final
decoration → DropdownDecoration?
Decoration for customizing the dropdown's appearance (e.g., border, padding, etc.).
final
disabled → bool
final
Default value is DropdownType.expandable, and it's used to switch between the expandable, and the overlay appearance
final
expandableSelectorBottomMargin → double
Bottom margin when the DropdownType is set to DropdownType.expandable Default is set to 4
final
hashCode → int
The hash code for this object.
no setterinherited
hintText → String?
Placeholder text displayed when no value is selected.
final
initData → List<DropDownModel<T>>
Initial list of dropdown options.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelText → String?
The label text for the dropdown field.
final
nestedInitData → List<DropDownNestedModel<T>>?
Initial list of dropdown options.
final
onOptionSelected → dynamic Function(DropDownModel<T>?)?
Callback triggered when an option from the dropdown is selected.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedValue → DropDownModel<T>?
The currently selected dropdown value.
final
validator → String? Function(DropDownModel<T>?)?
Provides a DropDownModel object if selected, and null if not
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited